@@ -51,6 +51,7 @@ struct ParserClass {
     std::vector<std::string> metadata;
     std::vector<std::string> fileList;
     MetricNames metric_names;
+    Metrics timestamps;
 
     explicit ParserClass() {
         pParser = new FTDCParser();
@@ -61,6 +62,12 @@ struct ParserClass {
         fileList.emplace_back(file);
         logging::core::get()->set_filter(logging::trivial::severity >  logging::trivial::error);
         int n = pParser->parseFiles(file, false, false);
+
+        // Timestamps, metric names, and metadata as fields in python
+        metric_names = pParser->getMetricsNames();
+        metadata = pParser->getMetadata();
+        timestamps = pParser->getMetric("start");
+
         return n;
     }
 
@@ -69,7 +76,6 @@ struct ParserClass {
         // if it exists an it is a directory, pop and push contents
         if (std::filesystem::exists(dir) && std::filesystem::is_directory(dir)) {
 
-
             for (auto&& fileInPath : std::filesystem::directory_iterator(dir))
                 fileList.push_back(fileInPath.path().string());
 
@@ -77,16 +83,16 @@ struct ParserClass {
             std::sort(fileList.begin(), fileList.end());
             int n = pParser->parseFiles(fileList, false, false);
 
-            metadata = pParser->getMetadata();
-
-            // metric names
+            // metric names and metadata as fields in python
             metric_names = pParser->getMetricsNames();
+            metadata = pParser->getMetadata();
+            timestamps = pParser->getMetric("start");
 
             return n;
         }
         return -1;
     }
-    Metrics  timestamps() {
+    Metrics  get_timestamps() {
         return pParser->getMetric("start");
     }
     Metrics  getMetric(std::string metricName) {
@@ -112,7 +118,7 @@ struct ParserClass {
         py::array_t<uint64_t , py::array::c_style> a;
         a.resize({(int)metricNames.size(), (int)pParser->getMetricLength()});
         std::fill(a.mutable_data(), a.mutable_data() + a.size(), 42);
-        //auto  dims = a.ndim();
+
         auto r = a.mutable_unchecked();
         for (py::ssize_t i=0; i<r.shape(0); i++) {
             auto element = pParser->getMetric(metricNames[i]);
@@ -183,7 +189,7 @@ PYBIND11_MODULE(_core, m) {
         .def("get_metric_sample_count", &ParserClass::getMetricSampleCount)
         .def_readonly("metric_names", &ParserClass::metric_names)
         .def_readonly("metadata", &ParserClass::metadata)
-        .def("timestamps", &ParserClass::timestamps)
+        .def_readonly("timestamps", &ParserClass::timestamps)
         .def("get_metric_numpy", &ParserClass::getMetricAsNumpyArray)
         .def("get_metrics_list_numpy", &ParserClass::getMetricListAsNumpyArray)
         .def("get_metrics_list_numpy_matrix", &ParserClass::getMetricListAsNumpyMatrix)
